#
# spec file for package bluez-qt
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   6
%define _libname KF5BluezQt
%define _tar_path 5.71
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
# Only needed for the package signature condition
%bcond_without lang
Name:           bluez-qt
Version:        5.71.0
Release:        lp152.1.1
Summary:        Async Bluez wrapper library
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(Qt5Core) >= 5.12.0
BuildRequires:  cmake(Qt5DBus) >= 5.12.0
BuildRequires:  cmake(Qt5Gui) >= 5.12.0
BuildRequires:  cmake(Qt5Network) >= 5.12.0
BuildRequires:  cmake(Qt5Qml) >= 5.12.0
BuildRequires:  cmake(Qt5Widgets) >= 5.12.0
BuildRequires:  pkgconfig(udev)

%description
Async Bluez wrapper library.

%package -n lib%{_libname}%{sonum}
Summary:        Async Bluez wrapper library - development files
Group:          System/GUI/KDE

# KUF only due to version number overlapping
Obsoletes:      lib%{_libname}5

%description -n lib%{_libname}%{sonum}
Async Bluez wrapper library.

%package imports
Summary:        Async Bluez wrapper library
Group:          System/GUI/KDE
%requires_ge    libQtQuick5
Supplements:    packageand(lib%{_libname}%{sonum}:libQtQuick5)

%description imports
Async Bluez wrapper library.
QML imports.

%package udev
Summary:        bluez-qt integration with udev
Group:          System/Base
Requires:       udev

%description udev
Async Bluez wrapper library.
Udev rules.

%package devel
Summary:        Async Bluez wrapper library - development files
Group:          Development/Libraries/C and C++
Requires:       lib%{_libname}%{sonum} = %{version}
Requires:       cmake(Qt5Core) >= 5.12.0

%description devel
Development files for QBluez Async Bluez wrapper library.

%prep
%setup -q

%build
  %cmake_kf5 -d build -- -DUDEV_RULES_INSTALL_DIR="%{_udevrulesdir}"
  %cmake_build

%install
  %kf5_makeinstall -C build
  %fdupes -s %{buildroot}

%post -n lib%{_libname}%{sonum} -p /sbin/ldconfig
%postun -n lib%{_libname}%{sonum} -p /sbin/ldconfig

%files -n lib%{_libname}%{sonum}
%license COPYING.LIB
%doc README*
%{_libqt5_libdir}/lib%{_libname}*.so.*
%{_kf5_debugdir}/bluezqt.categories

%files imports
%license COPYING.LIB
%doc README*
%{_kf5_qmldir}/

%files udev
%{_udevrulesdir}/61-kde-bluetooth-rfkill.rules

%files devel
%{_kf5_libdir}/cmake/%{_libname}/
%{_kf5_libdir}/lib%{_libname}*.so
%{_kf5_includedir}/
%{_kf5_mkspecsdir}/qt_BluezQt.pri

%changelog
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Fix errors in the QRegularExpression porting commit
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Use ecm_qt_install_logging_categories over manual categories file
  * Convert license statements to SPDX
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * Remove extra flush when we close file it will flush
  * endl is Qt:: namespaced in qt5.15. Port to \n and flush
    when QTextStream is not on a QFile
* Fri Jan 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavor.
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Port QRegExp to QRegularExpression
  * Add Battery1 interface
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Fix minor issue found by EBN and typos
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * [Bluez-Qt] Port away from deprecated QSharedPointer::data() method.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Remove unused includes
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Fix crash due to the q pointer never being initialized.
  * Don't include bluezqt_dbustypes.h from installed headers
  * Fix compiler warnings
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Add MediaTransport API
  * Install in new logging directory when we use kf5 5.59.0
  * Add LE Advertising and GATT APIs
  * Minor change to prevent force push removed commits from returning
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Add Bluez API to DBus XML parser/generator
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- No code changes since 5.57.0
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * It compiles fine without foreach
  * Replace Q_FOREACH with C++11 for
  * Move Media interface into Adapter
  * Manager: Don't require Media1 interface for initialization (kde#405478)
  * Device: Check object path in interfaces removed slot (kde#403289)
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * No code changes since 5.55.0
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix fall-through warning
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * No code changes since 5.53.0
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Remove qt prefix include
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Add Media and MediaEndpoint API header generation
  * Fix new syntax
* Mon Oct 22 2018 wbauer@tmo.at
- Use %%{_udevrulesdir} macro to specify the install directory for
  udev rules instead of a hard-coded path
* Fri Oct 19 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Fix install directory for udev rules (boo#1112598)
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Implement Media and MediaEndpoint API
  * Make sure to compile with strict compile flags
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * None
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * None
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Update D-Bus xml files to use "Out*" for signal type Qt annotations
  * Add signal for devices's address changing
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Add missing override
  * Use override
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * None
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * None
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * No need to initialize m_usableAdapterwith nullptr
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Autogenerate debug file
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Do not leak rfkill file descriptors. (kde#386886)
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * None
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * autotests: remove now unnecessary compat code
  * autotests: fix failure to find fakebluez in the bin dir.
  * Autotests: Fix finding fakebluez binary (kde#383453)
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Autotests: repair finding helper binary in current setup
  * autotests: fix running with CTEST_PARALLEL_LEVEL=8
  * autotests: prepare for CMAKE_RUNTIME_OUTPUT_DIRECTORY being set
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * API dox: note CamelCase includes by @class tag
  * API dox: add namespace to classes named in README.md
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Pass an explicit list of arguments. This prevents QProcess from trying to handle our space containing path through a shell
  * Fix property changes being missed immediately after an obejct is added (kde#377405)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Add .arcconfig
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Provide device type for Low Energy devices
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Mon Nov 14 2016 hrvoje.senjan@gmail.com
- (Build)Require udev so udevrulesdir gets owned
* Mon Nov 14 2016 alarrosa@suse.com
- Specify the file to be included in bluez-qt-udev instead of
  owning the /lib/udev/ directory.
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Fix crash when trying to add device to unknown adapter (kde#364416)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Fix include dir in pri file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * ObexManager: Split error messages for missing objects
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * isBluetoothOperational now also depends on unblocked rfkill
  * Fix determining global state of rfkill switch
  * QML API: Mark properties without notify signal as constants
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Fix fakebluez crash in obexmanagertest with ASAN
  * Forward declare all exported classes in types.h
  * ObexTransfer: Set error when transfer session is removed
  * Utils: Hold pointers to managers instances
  * ObexTransfer: Set error when org.bluez.obex crashes
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Don't forward deviceChanged signal after device was removed
    (kde#351051)
  * Respect -DBUILD_TESTING=OFF
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Remove all devices from adapter before removing the adapter
    (kde#349363)
  * Update links in README.md
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
* Fri Apr 10 2015 hrvoje.senjan@gmail.com
- Initial package
